==> haskell-case-insensitive-1.2.1.0-278-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-DJzIJZH4DdL5KuISGpY4ML
key:                  case-insensitive-1.2.1.0-DJzIJZH4DdL5KuISGpY4ML
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  76551c77691e9d04bc5956b55567c960
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-DJzIJZH4DdL5KuISGpY4ML
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0
    hashable-1.4.4.0-D3m6G7BPJON5VQ2FLdROoK text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.1.0-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
key:                  case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  c74d22cdec4e90f14c0f0c9bff87a9bf
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0
    hashable-1.4.4.0-AmJtI56ndXc1GvGfBNNgwb text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
